# cuddly-octo-funicular

[![CI](https://github.com/yu9824/cuddly-octo-funicular/actions/workflows/CI.yaml/badge.svg)](https://github.com/yu9824/cuddly-octo-funicular/actions/workflows/CI.yaml)
[![docs](https://github.com/yu9824/cuddly-octo-funicular/actions/workflows/docs.yaml/badge.svg)](https://github.com/yu9824/cuddly-octo-funicular/actions/workflows/docs.yaml)

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

<!--
[![python_badge](https://img.shields.io/pypi/pyversions/cuddly-octo-funicular)](https://pypi.org/project/cuddly-octo-funicular/)
[![license_badge](https://img.shields.io/pypi/l/cuddly-octo-funicular)](https://pypi.org/project/cuddly-octo-funicular/)
[![PyPI version](https://badge.fury.io/py/cuddly-octo-funicular.svg)](https://pypi.org/project/cuddly-octo-funicular/)
[![Downloads](https://static.pepy.tech/badge/cuddly-octo-funicular)](https://pepy.tech/project/cuddly-octo-funicular)

[![Conda Version](https://img.shields.io/conda/vn/conda-forge/cuddly-octo-funicular.svg)](https://anaconda.org/conda-forge/cuddly-octo-funicular)
[![Conda Platforms](https://img.shields.io/conda/pn/conda-forge/cuddly-octo-funicular.svg)](https://anaconda.org/conda-forge/cuddly-octo-funicular)
-->

Before [pep518](https://peps.python.org/pep-0518/)
- `setup.py`
- `setup.cfg`
- `ruff.toml`

After [pep518](https://peps.python.org/pep-0518/)
- `pyproject.toml`
